# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-21 19:18
from __future__ import unicode_literals

import dj_bioinformatics_protein.fields
import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dj_bioinformatics_protein', '0003_auto_20160227_0008'),
    ]

    operations = [
        migrations.AlterField(
            model_name='alignment',
            name='alignment_method',
            field=models.CharField(choices=[('H', 'hhsearch'), ('S', 'sparksX'), ('U', 'user')], max_length=1),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='full_query_sequence',
            field=dj_bioinformatics_protein.fields.AminoAcidSequenceField(max_length=5000, validators=[django.core.validators.RegexValidator('^[ACDEFGHIKLMNPQRSTVWYX]*$', 'Only uppercase amino acid abbreviations are allowed, or X (non canonical residues).')]),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='modified_query_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000, null=True, validators=[django.core.validators.RegexValidator('^[ACDEFGHIKLMNPQRSTVWYX\\-]*$', 'Only uppercase amino acid abbreviations or dashes are allowed, or X (non canonical residues).')]),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='modified_target_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000, null=True, validators=[django.core.validators.RegexValidator('^[ACDEFGHIKLMNPQRSTVWYX\\-]*$', 'Only uppercase amino acid abbreviations or dashes are allowed, or X (non canonical residues).')]),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='query_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000, validators=[django.core.validators.RegexValidator('^[ACDEFGHIKLMNPQRSTVWYX\\-]*$', 'Only uppercase amino acid abbreviations or dashes are allowed, or X (non canonical residues).')]),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='target_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000, validators=[django.core.validators.RegexValidator('^[ACDEFGHIKLMNPQRSTVWYX\\-]*$', 'Only uppercase amino acid abbreviations or dashes are allowed, or X (non canonical residues).')]),
        ),
        migrations.AlterField(
            model_name='fasta',
            name='sequence',
            field=dj_bioinformatics_protein.fields.AminoAcidSequenceField(max_length=5000, validators=[django.core.validators.RegexValidator('^[ACDEFGHIKLMNPQRSTVWYX]*$', 'Only uppercase amino acid abbreviations are allowed, or X (non canonical residues).')]),
        ),
    ]
