# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-02-27 00:08
from __future__ import unicode_literals

import dj_bioinformatics_protein.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dj_bioinformatics_protein', '0002_remove_alignment_sha256'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='multiplealignments',
            name='full_query_sequence',
        ),
        migrations.RemoveField(
            model_name='alignment',
            name='multiple_alignments',
        ),
        migrations.RemoveField(
            model_name='alignment',
            name='query_tag',
        ),
        migrations.RemoveField(
            model_name='alignment',
            name='target_tag',
        ),
        migrations.AddField(
            model_name='alignment',
            name='query_description',
            field=models.CharField(max_length=1000, null=True),
        ),
        migrations.AddField(
            model_name='alignment',
            name='target_description',
            field=models.CharField(max_length=1000, null=True),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='alignment_method',
            field=models.CharField(choices=[(b'H', b'hhsearch'), (b'S', b'sparksX'), (b'U', b'user')], max_length=1),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='full_query_sequence',
            field=dj_bioinformatics_protein.fields.AminoAcidSequenceField(max_length=5000),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='modified_query_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000, null=True),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='modified_target_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000, null=True),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='query_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='target_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000),
        ),
        migrations.AlterField(
            model_name='fasta',
            name='comments',
            field=models.TextField(null=True),
        ),
        migrations.AlterField(
            model_name='fasta',
            name='description',
            field=models.CharField(default='', max_length=1000),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='fasta',
            name='sequence',
            field=dj_bioinformatics_protein.fields.AminoAcidSequenceField(max_length=5000),
        ),
        migrations.DeleteModel(
            name='MultipleAlignments',
        ),
    ]
