# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-27 20:14
from __future__ import unicode_literals

import dj_bioinformatics_protein.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('dj_bioinformatics_protein', '0004_auto_20170621_1918'),
    ]

    operations = [
        migrations.AlterField(
            model_name='alignment',
            name='full_query_sequence',
            field=dj_bioinformatics_protein.fields.AminoAcidSequenceField(max_length=5000),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='modified_query_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000, null=True),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='modified_target_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000, null=True),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='query_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000),
        ),
        migrations.AlterField(
            model_name='alignment',
            name='target_aln_seq',
            field=dj_bioinformatics_protein.fields.AminoAcidAlignmentField(max_length=5000),
        ),
        migrations.AlterField(
            model_name='fasta',
            name='sequence',
            field=dj_bioinformatics_protein.fields.AminoAcidSequenceField(max_length=5000),
        ),
    ]
